@@ -50,9 +50,6 @@
 #include "cally-root.h"
 #include "cally-stage.h"
 
-static void cally_util_class_init (CallyUtilClass	*klass);
-static void cally_util_init       (CallyUtil *cally_util);
-
 /* atkutil.h */
 
 static guint                 cally_util_add_global_event_listener    (GSignalEmissionHook listener,
@@ -183,7 +180,10 @@ cally_util_add_global_event_listener (GSignalEmissionHook listener,
 
   split_string = g_strsplit (event_type, ":", 3);
 
-  rc = add_listener (listener, split_string[1], split_string[2], event_type);
+  if (g_strv_length (split_string) == 3)
+    rc = add_listener (listener, split_string[1], split_string[2], event_type);
+
+  g_strfreev (split_string);
 
   return rc;
 }
@@ -233,7 +233,7 @@ static guint
 cally_util_add_key_event_listener (AtkKeySnoopFunc  listener,
                                    gpointer         data)
 {
-  static guint key=0;
+  static guint key = 1;
   CallyKeyEventInfo *event_info = NULL;
 
   if (!key_listener_list)
@@ -261,6 +261,8 @@ cally_util_remove_key_event_listener (guint remove_listener)
 
   if (g_hash_table_size (key_listener_list) == 0)
     {
+      g_hash_table_destroy (key_listener_list);
+      key_listener_list = NULL;
       cally_util_simulate_snooper_remove ();
     }
 }
