@@ -181,6 +181,7 @@ struct _ClutterActor
  *   clutter_actor_set_offscreen_redirect() for details.
  * @paint_node: virtual function for creating paint nodes and attaching
  *   them to the render tree
+ * @touch_event: signal class closure for #ClutterActor::touch-event
  *
  * Base class for actors.
  */
@@ -263,9 +264,12 @@ struct _ClutterActorClass
   void     (* paint_node)           (ClutterActor         *self,
                                      ClutterPaintNode     *root);
 
+  gboolean (* touch_event)          (ClutterActor         *self,
+                                     ClutterTouchEvent    *event);
+
   /*< private >*/
   /* padding for future expansion */
-  gpointer _padding_dummy[27];
+  gpointer _padding_dummy[26];
 };
 
 /**
@@ -502,6 +506,11 @@ CLUTTER_AVAILABLE_IN_1_10
 void                            clutter_actor_get_content_scaling_filters       (ClutterActor               *self,
                                                                                  ClutterScalingFilter       *min_filter,
                                                                                  ClutterScalingFilter       *mag_filter);
+CLUTTER_AVAILABLE_IN_1_12
+void                            clutter_actor_set_content_repeat                (ClutterActor               *self,
+                                                                                 ClutterContentRepeat        repeat);
+CLUTTER_AVAILABLE_IN_1_12
+ClutterContentRepeat            clutter_actor_get_content_repeat                (ClutterActor               *self);
 CLUTTER_AVAILABLE_IN_1_10
 void                            clutter_actor_get_content_box                   (ClutterActor               *self,
                                                                                  ClutterActorBox            *box);
