@@ -35,18 +35,15 @@
  *   <listitem><para>all children are arranged on a single
  *   line;</para></listitem>
  *   <listitem><para>the axis used is controlled by the
- *   #ClutterBoxLayout:vertical boolean property;</para></listitem>
+ *   #ClutterBoxLayout:orientation property;</para></listitem>
  *   <listitem><para>the order of the packing is determined by the
  *   #ClutterBoxLayout:pack-start boolean property;</para></listitem>
  *   <listitem><para>each child will be allocated to its natural
- *   size or, if set to expand, the available size;</para></listitem>
- *   <listitem><para>if a child is set to fill on either (or both)
- *   axis, its allocation will match all the available size; the
- *   fill layout property only makes sense if the expand property is
- *   also set;</para></listitem>
- *   <listitem><para>if a child is set to expand but not to fill then
- *   it is possible to control the alignment using the X and Y alignment
- *   layout properties.</para></listitem>
+ *   size or, if #ClutterActor:x-expand/#ClutterActor:y-expand
+ *   is set, the available size;</para></listitem>
+ *   <listitem><para>honours the #ClutterActor's #ClutterActor:x-align
+ *   and #ClutterActor:y-align properties to fill the available
+ *   size;</para></listitem>
  *   <listitem><para>if the #ClutterBoxLayout:homogeneous boolean property
  *   is set, then all widgets will get the same size, ignoring expand
  *   settings and the preferred sizes</para></listitem>
@@ -62,10 +59,6 @@
  * It is possible to control the spacing between children of a
  * #ClutterBoxLayout by using clutter_box_layout_set_spacing().
  *
- * In order to set the layout properties when packing an actor inside a
- * #ClutterBoxLayout you should use the clutter_box_layout_pack()
- * function.
- *
  * #ClutterBoxLayout is available since Clutter 1.2
  */
 
@@ -109,7 +102,6 @@ struct _ClutterBoxLayoutPrivate
   ClutterOrientation orientation;
 
   guint is_pack_start  : 1;
-  guint use_animations : 1;
   guint is_homogeneous : 1;
 };
 
@@ -120,12 +112,9 @@ struct _ClutterBoxChild
   ClutterBoxAlignment x_align;
   ClutterBoxAlignment y_align;
 
-  ClutterActorBox last_allocation;
-
   guint x_fill              : 1;
   guint y_fill              : 1;
   guint expand              : 1;
-  guint has_last_allocation : 1;
 };
 
 enum
@@ -149,10 +138,8 @@ enum
   PROP_VERTICAL,
   PROP_HOMOGENEOUS,
   PROP_PACK_START,
-  PROP_USE_ANIMATIONS,
-  PROP_EASING_MODE,
-  PROP_EASING_DURATION,
   PROP_ORIENTATION,
+  PROP_EASING_DURATION,
 
   PROP_LAST
 };
@@ -407,8 +394,6 @@ clutter_box_child_init (ClutterBoxChild *self)
   self->x_fill = self->y_fill = FALSE;
 
   self->expand = FALSE;
-
-  self->has_last_allocation = FALSE;
 }
 
 static gdouble
@@ -620,9 +605,12 @@ allocate_box_child (ClutterBoxLayout       *self,
                     ClutterContainer       *container,
                     ClutterActor           *child,
                     ClutterActorBox        *child_box,
-                    ClutterAllocationFlags  flags)
+                    ClutterAllocationFlags  flags,
+                    gboolean                use_animations,
+                    ClutterAnimationMode    easing_mode,
+                    guint                   easing_duration,
+                    guint                   easing_delay)
 {
-  ClutterBoxLayoutPrivate *priv = self->priv;
   ClutterBoxChild *box_child;
   ClutterLayoutMeta *meta;
 
@@ -637,21 +625,29 @@ allocate_box_child (ClutterBoxLayout       *self,
                 child_box->x2 - child_box->x1,
                 child_box->y2 - child_box->y1);
 
-  if (priv->use_animations)
+  if (use_animations)
     {
       clutter_actor_save_easing_state (child);
-      clutter_actor_set_easing_mode (child, priv->easing_mode);
-      clutter_actor_set_easing_duration (child, priv->easing_duration);
+      clutter_actor_set_easing_mode (child, easing_mode);
+      clutter_actor_set_easing_duration (child, easing_duration);
+      clutter_actor_set_easing_delay (child, easing_delay);
     }
 
-  clutter_actor_allocate_align_fill (child, child_box,
-                                     get_box_alignment_factor (box_child->x_align),
-                                     get_box_alignment_factor (box_child->y_align),
-                                     box_child->x_fill,
-                                     box_child->y_fill,
-                                     flags);
+  /* call allocate() instead of allocate_align_fill() if the actor needs
+   * expand in either direction. this will honour the actors alignment settings
+   */
+  if (clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_HORIZONTAL) ||
+      clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_VERTICAL))
+    clutter_actor_allocate (child, child_box, flags);
+  else
+    clutter_actor_allocate_align_fill (child, child_box,
+                                       get_box_alignment_factor (box_child->x_align),
+                                       get_box_alignment_factor (box_child->y_align),
+                                       box_child->x_fill,
+                                       box_child->y_fill,
+                                       flags);
 
-  if (priv->use_animations)
+  if (use_animations)
     clutter_actor_restore_easing_state (child);
 }
 
@@ -689,6 +685,7 @@ count_expand_children (ClutterLayoutManager *layout,
                        gint                 *visible_children,
                        gint                 *expand_children)
 {
+  ClutterBoxLayoutPrivate *priv = CLUTTER_BOX_LAYOUT (layout)->priv;
   ClutterActor *actor, *child;
   ClutterActorIter iter;
 
@@ -709,7 +706,8 @@ count_expand_children (ClutterLayoutManager *layout,
                                                         container,
                                                         child);
 
-          if (CLUTTER_BOX_CHILD (meta)->expand)
+          if (clutter_actor_needs_expand (child, priv->orientation) ||
+              CLUTTER_BOX_CHILD (meta)->expand)
             *expand_children += 1;
         }
     }
@@ -852,6 +850,10 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
   gint x = 0, y = 0, i;
   gint child_size;
 
+  gboolean use_animations;
+  ClutterAnimationMode easing_mode;
+  guint easing_duration, easing_delay;
+
   count_expand_children (layout, container, &nvis_children, &nexpand_children);
 
   CLUTTER_NOTE (LAYOUT, "BoxLayout for %s: visible=%d, expand=%d",
@@ -872,6 +874,11 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
 
   actor = CLUTTER_ACTOR (container);
 
+  use_animations = clutter_layout_manager_get_easing_state (layout,
+                                                            &easing_mode,
+                                                            &easing_duration,
+                                                            &easing_delay);
+
   /* Retrieve desired size for visible children. */
   i = 0;
   clutter_actor_iter_init (&iter, actor);
@@ -1020,7 +1027,8 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
         {
           child_size = sizes[i].minimum_size;
 
-          if (box_child->expand)
+          if (clutter_actor_needs_expand (child, priv->orientation) ||
+              box_child->expand)
             {
               child_size += extra;
 
@@ -1035,7 +1043,8 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
       /* Assign the child's position. */
       if (priv->orientation == CLUTTER_ORIENTATION_VERTICAL)
         {
-          if (box_child->y_fill)
+          if (clutter_actor_needs_expand (child, priv->orientation) ||
+              box_child->y_fill)
             {
               child_allocation.y1 = y;
               child_allocation.y2 = child_allocation.y1 + MAX (1.0, child_size);
@@ -1060,7 +1069,8 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
         }
       else /* CLUTTER_ORIENTATION_HORIZONTAL */
         {
-          if (box_child->x_fill)
+          if (clutter_actor_needs_expand (child, priv->orientation) ||
+              box_child->x_fill)
             {
               child_allocation.x1 = x;
               child_allocation.x2 = child_allocation.x1 + MAX (1.0, child_size);
@@ -1099,7 +1109,11 @@ clutter_box_layout_allocate (ClutterLayoutManager   *layout,
                             container,
                             child,
                             &child_allocation,
-                            flags);
+                            flags,
+                            use_animations,
+                            easing_mode,
+                            easing_duration,
+                            easing_delay);
 
         i += 1;
     }
@@ -1135,18 +1149,6 @@ clutter_box_layout_set_property (GObject      *gobject,
       clutter_box_layout_set_pack_start (self, g_value_get_boolean (value));
       break;
 
-    case PROP_USE_ANIMATIONS:
-      clutter_box_layout_set_use_animations (self, g_value_get_boolean (value));
-      break;
-
-    case PROP_EASING_MODE:
-      clutter_box_layout_set_easing_mode (self, g_value_get_ulong (value));
-      break;
-
-    case PROP_EASING_DURATION:
-      clutter_box_layout_set_easing_duration (self, g_value_get_uint (value));
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
       break;
@@ -1184,18 +1186,6 @@ clutter_box_layout_get_property (GObject    *gobject,
       g_value_set_boolean (value, priv->is_pack_start);
       break;
 
-    case PROP_USE_ANIMATIONS:
-      g_value_set_boolean (value, priv->use_animations);
-      break;
-
-    case PROP_EASING_MODE:
-      g_value_set_ulong (value, priv->easing_mode);
-      break;
-
-    case PROP_EASING_DURATION:
-      g_value_set_uint (value, priv->easing_duration);
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
       break;
@@ -1300,69 +1290,12 @@ clutter_box_layout_class_init (ClutterBoxLayoutClass *klass)
                        0, G_MAXUINT, 0,
                        CLUTTER_PARAM_READWRITE);
 
-  /**
-   * ClutterBoxLayout:use-animations:
-   *
-   * Whether the #ClutterBoxLayout should animate changes in the
-   * layout, overriding the easing state of the children.
-   *
-   * Since: 1.2
-   *
-   * Deprecated: 1.12: #ClutterBoxLayout will honour the easing state
-   *   of the children when allocating them.
-   */
-  obj_props[PROP_USE_ANIMATIONS] =
-    g_param_spec_boolean ("use-animations",
-                          P_("Use Animations"),
-                          P_("Whether layout changes should be animated"),
-                          FALSE,
-                          CLUTTER_PARAM_READWRITE);
-
-  /**
-   * ClutterBoxLayout:easing-mode:
-   *
-   * The easing mode for the animations, in case
-   * #ClutterBoxLayout:use-animations is set to %TRUE.
-   *
-   * The easing mode has the same semantics of #ClutterAnimation:mode: it can
-   * either be a value from the #ClutterAnimationMode enumeration, like
-   * %CLUTTER_EASE_OUT_CUBIC, or a logical id as returned by
-   * clutter_alpha_register_func().
-   *
-   * The default value is %CLUTTER_EASE_OUT_CUBIC.
-   *
-   * Since: 1.2
-   *
-   * Deprecated: 1.12: The #ClutterBoxLayout will honour the easing state of
-   *   the children when allocating them.
-   */
-  obj_props[PROP_EASING_MODE] =
-    g_param_spec_ulong ("easing-mode",
-                        P_("Easing Mode"),
-                        P_("The easing mode of the animations"),
-                        0, G_MAXULONG,
-                        CLUTTER_EASE_OUT_CUBIC,
-                        CLUTTER_PARAM_READWRITE);
-
-  /**
-   * ClutterBoxLayout:easing-duration:
-   *
-   * The duration of the animations, in case #ClutterBoxLayout:use-animations
-   * is set to %TRUE.
-   *
-   * The duration is expressed in milliseconds.
-   *
-   * Since: 1.2
-   *
-   * Deprecated: 1.12: The #ClutterBoxLayout will honour the easing state of
-   *   the children when allocating them.
-   */
+  /* a leftover to be compatible to the previous implementation */
   obj_props[PROP_EASING_DURATION] =
     g_param_spec_uint ("easing-duration",
                        P_("Easing Duration"),
                        P_("The duration of the animations"),
-                       0, G_MAXUINT,
-                       500,
+                       0, G_MAXUINT, 500,
                        CLUTTER_PARAM_READWRITE);
 
   gobject_class->set_property = clutter_box_layout_set_property;
@@ -1381,10 +1314,6 @@ clutter_box_layout_init (ClutterBoxLayout *layout)
   priv->is_homogeneous = FALSE;
   priv->is_pack_start = FALSE;
   priv->spacing = 0;
-
-  priv->use_animations = FALSE;
-  priv->easing_mode = CLUTTER_EASE_OUT_CUBIC;
-  priv->easing_duration = 500;
 }
 
 /**
@@ -1677,6 +1606,11 @@ clutter_box_layout_get_pack_start (ClutterBoxLayout *layout)
  * and sets the layout properties
  *
  * Since: 1.2
+ * Deprecated: 1.12: #ClutterBoxLayout honours #ClutterActor's
+ *   align and expand properties. The preferred way is adding
+ *   the @actor with clutter_actor_add_child() and setting
+ *   #ClutterActor:x-align, #ClutterActor:y-align,
+ *   #ClutterActor:x-expand and #ClutterActor:y-expand
  */
 void
 clutter_box_layout_pack (ClutterBoxLayout    *layout,
@@ -1728,6 +1662,8 @@ clutter_box_layout_pack (ClutterBoxLayout    *layout,
  * inside @layout
  *
  * Since: 1.2
+ * Deprecated: 1.12: #ClutterBoxLayout will honour #ClutterActor's
+ *   #ClutterActor:x-align and #ClutterActor:y-align properies
  */
 void
 clutter_box_layout_set_alignment (ClutterBoxLayout    *layout,
@@ -1782,6 +1718,8 @@ clutter_box_layout_set_alignment (ClutterBoxLayout    *layout,
  * as set using clutter_box_layout_pack() or clutter_box_layout_set_alignment()
  *
  * Since: 1.2
+ * Deprecated: 1.12: #ClutterBoxLayout will honour #ClutterActor's
+ *   #ClutterActor:x-align and #ClutterActor:y-align properies
  */
 void
 clutter_box_layout_get_alignment (ClutterBoxLayout    *layout,
@@ -1840,6 +1778,8 @@ clutter_box_layout_get_alignment (ClutterBoxLayout    *layout,
  * inside @layout
  *
  * Since: 1.2
+ * Deprecated: 1.12: #ClutterBoxLayout will honour #ClutterActor's
+ *   #ClutterActor:x-align and #ClutterActor:y-align properies
  */
 void
 clutter_box_layout_set_fill (ClutterBoxLayout *layout,
@@ -1894,6 +1834,8 @@ clutter_box_layout_set_fill (ClutterBoxLayout *layout,
  * as set using clutter_box_layout_pack() or clutter_box_layout_set_fill()
  *
  * Since: 1.2
+ * Deprecated: 1.12: #ClutterBoxLayout will honour #ClutterActor's
+ *   #ClutterActor:x-align and #ClutterActor:y-align properies
  */
 void
 clutter_box_layout_get_fill (ClutterBoxLayout *layout,
@@ -1950,6 +1892,8 @@ clutter_box_layout_get_fill (ClutterBoxLayout *layout,
  * Sets whether @actor should expand inside @layout
  *
  * Since: 1.2
+ * Deprecated: 1.12: #ClutterBoxLayout will honour #ClutterActor's
+ *   #ClutterActor:x-expand and #ClutterActor:y-expand properies
  */
 void
 clutter_box_layout_set_expand (ClutterBoxLayout *layout,
@@ -2002,6 +1946,8 @@ clutter_box_layout_set_expand (ClutterBoxLayout *layout,
  * Return value: %TRUE if the #ClutterActor should expand, %FALSE otherwise
  *
  * Since: 1.2
+ * Deprecated: 1.12: #ClutterBoxLayout will honour #ClutterActor's
+ *   #ClutterActor:x-expand and #ClutterActor:y-expand properies
  */
 gboolean
 clutter_box_layout_get_expand (ClutterBoxLayout *layout,
@@ -2060,25 +2006,17 @@ clutter_box_layout_get_expand (ClutterBoxLayout *layout,
  *
  * Since: 1.2
  *
- * Deprecated: 1.12: The layout manager will honour the easing state
- *   of the children when allocating them.
+ * Deprecated: 1.12: #ClutterBoxLayout will honour the
+ *   #ClutterLayoutManager:use-animations property
  */
 void
 clutter_box_layout_set_use_animations (ClutterBoxLayout *layout,
                                        gboolean          animate)
 {
-  ClutterBoxLayoutPrivate *priv;
-
   g_return_if_fail (CLUTTER_IS_BOX_LAYOUT (layout));
 
-  priv = layout->priv;
-
-  if (priv->use_animations != animate)
-    {
-      priv->use_animations = animate;
-
-      g_object_notify (G_OBJECT (layout), "use-animations");
-    }
+  clutter_layout_manager_set_use_animations (CLUTTER_LAYOUT_MANAGER (layout),
+                                             animate);
 }
 
 /**
@@ -2091,14 +2029,19 @@ clutter_box_layout_set_use_animations (ClutterBoxLayout *layout,
  *
  * Since: 1.2
  *
- * Deprecated: 1.12
+ * Deprecated: 1.12: #ClutterBoxLayout will honour the
+ *   #ClutterLayoutManager:use-animations property
  */
 gboolean
 clutter_box_layout_get_use_animations (ClutterBoxLayout *layout)
 {
+  ClutterLayoutManager *manager;
+
   g_return_val_if_fail (CLUTTER_IS_BOX_LAYOUT (layout), FALSE);
 
-  return layout->priv->use_animations;
+  manager = CLUTTER_LAYOUT_MANAGER (layout);
+
+  return clutter_layout_manager_get_use_animations (manager);
 }
 
 /**
@@ -2112,25 +2055,17 @@ clutter_box_layout_get_use_animations (ClutterBoxLayout *layout)
  *
  * Since: 1.2
  *
- * Deprecated: 1.12: The layout manager will honour the easing state
- *   of the children when allocating them.
+ * Deprecated: 1.12: #ClutterBoxLayout will honour the
+ *   #ClutterLayoutManager:easing-mode property
  */
 void
 clutter_box_layout_set_easing_mode (ClutterBoxLayout *layout,
                                     gulong            mode)
 {
-  ClutterBoxLayoutPrivate *priv;
-
   g_return_if_fail (CLUTTER_IS_BOX_LAYOUT (layout));
 
-  priv = layout->priv;
-
-  if (priv->easing_mode != mode)
-    {
-      priv->easing_mode = mode;
-
-      g_object_notify (G_OBJECT (layout), "easing-mode");
-    }
+  clutter_layout_manager_set_easing_mode (CLUTTER_LAYOUT_MANAGER (layout),
+                                          mode);
 }
 
 /**
@@ -2143,15 +2078,20 @@ clutter_box_layout_set_easing_mode (ClutterBoxLayout *layout,
  *
  * Since: 1.2
  *
- * Deprecated: 1.12
+ * Deprecated: 1.12: #ClutterBoxLayout will honour the
+ *   #ClutterLayoutManager:easing-mode property
  */
 gulong
 clutter_box_layout_get_easing_mode (ClutterBoxLayout *layout)
 {
+  ClutterLayoutManager *manager;
+
   g_return_val_if_fail (CLUTTER_IS_BOX_LAYOUT (layout),
                         CLUTTER_EASE_OUT_CUBIC);
 
-  return layout->priv->easing_mode;
+  manager = CLUTTER_LAYOUT_MANAGER (layout);
+
+  return clutter_layout_manager_get_easing_mode (manager);
 }
 
 /**
@@ -2164,25 +2104,17 @@ clutter_box_layout_get_easing_mode (ClutterBoxLayout *layout)
  *
  * Since: 1.2
  *
- * Deprecated: 1.12: The layout manager will honour the easing state
- *   of the children when allocating them.
+ * Deprecated: 1.12: #ClutterBoxLayout will honour the
+ *   #ClutterLayoutManager:easing-duration property
  */
 void
 clutter_box_layout_set_easing_duration (ClutterBoxLayout *layout,
                                         guint             msecs)
 {
-  ClutterBoxLayoutPrivate *priv;
-
   g_return_if_fail (CLUTTER_IS_BOX_LAYOUT (layout));
 
-  priv = layout->priv;
-
-  if (priv->easing_duration != msecs)
-    {
-      priv->easing_duration = msecs;
-
-      g_object_notify (G_OBJECT (layout), "easing-duration");
-    }
+  clutter_layout_manager_set_easing_duration (CLUTTER_LAYOUT_MANAGER (layout),
+                                              msecs);
 }
 
 /**
@@ -2195,12 +2127,17 @@ clutter_box_layout_set_easing_duration (ClutterBoxLayout *layout,
  *
  * Since: 1.2
  *
- * Deprecated: 1.12
+ * Deprecated: 1.12: #ClutterBoxLayout will honour the
+ *   #ClutterLayoutManager:easing-duration property
  */
 guint
 clutter_box_layout_get_easing_duration (ClutterBoxLayout *layout)
 {
+  ClutterLayoutManager *manager;
+
   g_return_val_if_fail (CLUTTER_IS_BOX_LAYOUT (layout), 500);
 
-  return layout->priv->easing_duration;
+  manager = CLUTTER_LAYOUT_MANAGER (layout);
+
+  return clutter_layout_manager_get_easing_duration (manager);
 }
