@@ -4,6 +4,10 @@
 #define __CLUTTER_DEPRECATED_H_INSIDE__
 
 #include "deprecated/clutter-actor.h"
+#include "deprecated/clutter-alpha.h"
+#include "deprecated/clutter-animatable.h"
+#include "deprecated/clutter-animation.h"
+#include "deprecated/clutter-animator.h"
 #include "deprecated/clutter-backend.h"
 #include "deprecated/clutter-behaviour.h"
 #include "deprecated/clutter-behaviour-depth.h"
@@ -12,19 +16,26 @@
 #include "deprecated/clutter-behaviour-path.h"
 #include "deprecated/clutter-behaviour-rotate.h"
 #include "deprecated/clutter-behaviour-scale.h"
+#include "deprecated/clutter-bin-layout.h"
 #include "deprecated/clutter-box.h"
+#include "deprecated/clutter-cairo-texture.h"
 #include "deprecated/clutter-container.h"
 #include "deprecated/clutter-fixed.h"
 #include "deprecated/clutter-frame-source.h"
 #include "deprecated/clutter-group.h"
 #include "deprecated/clutter-keysyms.h"
 #include "deprecated/clutter-main.h"
+#include "deprecated/clutter-media.h"
 #include "deprecated/clutter-rectangle.h"
 #include "deprecated/clutter-score.h"
 #include "deprecated/clutter-shader.h"
+#include "deprecated/clutter-stage-manager.h"
 #include "deprecated/clutter-stage.h"
+#include "deprecated/clutter-state.h"
+#include "deprecated/clutter-texture.h"
 #include "deprecated/clutter-timeline.h"
 #include "deprecated/clutter-timeout-pool.h"
+#include "deprecated/clutter-util.h"
 
 #undef __CLUTTER_DEPRECATED_H_INSIDE__
 
