@@ -44,7 +44,7 @@
 
 /**
  * SECTION:clutter-grid-layout
- * @Short_description: Pack widgets in a rows and columns
+ * @Short_description: A layout manager for a grid of actors
  * @Title: ClutterGridLayout
  * @See_also: #ClutterTableLayout, #ClutterBoxLayout
  *
@@ -360,7 +360,7 @@ clutter_grid_request_update_child_attach (ClutterGridRequest *request,
 
           td = clutter_actor_get_text_direction (container);
           rtl = (td == CLUTTER_TEXT_DIRECTION_RTL) ? TRUE : FALSE;
-          side = rtl ? CLUTTER_GRID_POSITION_RIGHT : CLUTTER_GRID_POSITION_LEFT;
+          side = rtl ? CLUTTER_GRID_POSITION_LEFT : CLUTTER_GRID_POSITION_RIGHT;
         }
       else
         {
@@ -370,6 +370,8 @@ clutter_grid_request_update_child_attach (ClutterGridRequest *request,
         }
 
       sibling = clutter_actor_get_previous_sibling (actor);
+      if (sibling)
+        clutter_grid_layout_insert_next_to (request->grid, sibling, side);
       grid_attach_next_to (request->grid, actor, sibling, side,
                            CHILD_WIDTH (grid_child),
                            CHILD_HEIGHT (grid_child));
