@@ -51,13 +51,9 @@ GType clutter_input_device_get_type (void) G_GNUC_CONST;
 
 ClutterInputDeviceType  clutter_input_device_get_device_type    (ClutterInputDevice  *device);
 gint                    clutter_input_device_get_device_id      (ClutterInputDevice  *device);
-
-CLUTTER_AVAILABLE_IN_1_12
-gboolean                clutter_input_device_get_coords        (ClutterInputDevice   *device,
-                                                                ClutterEventSequence *sequence,
-                                                                ClutterPoint         *point);
-CLUTTER_AVAILABLE_IN_1_16
-ClutterModifierType     clutter_input_device_get_modifier_state (ClutterInputDevice  *device);
+void                    clutter_input_device_get_device_coords  (ClutterInputDevice  *device,
+                                                                 gint                *x,
+                                                                 gint                *y);
 ClutterActor *          clutter_input_device_get_pointer_actor  (ClutterInputDevice  *device);
 ClutterStage *          clutter_input_device_get_pointer_stage  (ClutterInputDevice  *device);
 const gchar *           clutter_input_device_get_device_name    (ClutterInputDevice  *device);
